This function detects fragmentation peaks for the Data-Independent Acquisition (DIA) analysis at ms level 1.
DIA_MS1_fragmentationPeakDetection(DIA_hrms_address, DIA_hrms_file, peaklist,
selectedIPApeaks, massError, smoothingWindowMS1, scanTolerance, nSpline,
topRatioPeakHeight, intensityThresholdFragment, pearsonRHOthreshold, outputDIAeic = NULL,
number_processing_threads = 1)A dataframe peaklist of co-detected DIA analysis.
path to the HRMS file
DIA HRMS file
IDSL.IPA peaklist
A vector of selected IDSL.IPA peaks only when a number of IDSL.IPA peaks from one peaklist is processed.
Mass accuracy in Da
number of scans for peak smoothing.
a scan tolerance to extend the chromatogram for better calculations.
number of points for further smoothing using a cubic spline smoothing method to add more points to calculate Pearson correlation rho values
The top percentage of the chromatographic peak to calculate Pearson correlation rho values
a value to represent intensity threshold for the fragment at the apex chromatogram scan
Minimum threshold for Pearson correlation rho values
When `NULL` DIA EICs are not plotted. `outputDIAeic` represents an address to save DIA EICs figures.
Number of processing threads for multi-threaded processing
Fakouri Baygi, S., Fernando, S., Hopke, P.K., Holsen, T.M., Crimmins, B.S. (2021). Nontargeted discovery of novel contaminants in the Great Lakes region: A comparison of fish fillets and fish consumers. Environmental Science & Technology, 55(6), 3765-3774, tools:::Rd_expr_doi("10.1021/acs.est.0c08507")